#' vembedr: Package for embedding video
#'
#' The vembedr package lets you embed video into your HTML pages for
#' these services:
#'
#'  - YouTube
#'  - Vimeo
#'  - Box
#'  - Microsoft Stream
#'
#' It provides two categories of functions:
#'
#'  - **embed** functions, to specify a video to embed:
#'      e.g. [embed_youtube()], [embed_url()]
#'  - **use** functions, to modify the embedding:
#'      e.g. [use_start_time()], [use_rounded()]
#'
#'  You can use the pipe (`|>` or `%>%`) to chain *embed function-calls* with
#'  *use function-calls*.
#'
#' @docType package
#' @name vembedr-package
NULL

## usethis namespace: start
#' @importFrom lifecycle deprecated
## usethis namespace: end
NULL
